@@ -1,19 +1,6 @@
-// Copyright (C)  2003  Dominique Devriese <devriese@kde.org>
+// SPDX-FileCopyrightText: 2003 Dominique Devriese <devriese@kde.org>
 
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 2
-// of the License, or (at your option) any later version.
-
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-// 02110-1301, USA.
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "native-filter.h"
 
@@ -121,6 +108,8 @@ KigDocument* KigFilterNative::load( const QString& file)
     if ( tempdir.isEmpty() )
       KIG_FILTER_PARSE_ERROR;
 
+    tempdir += QLatin1Char('/');
+
     QString tempname = file.section( '/', -1 );
     if ( file.endsWith( QLatin1String( ".kigz" ), Qt::CaseInsensitive ) )
     {
@@ -129,7 +118,7 @@ KigDocument* KigFilterNative::load( const QString& file)
     else
       KIG_FILTER_PARSE_ERROR;
     // reading compressed file
-    KTar ark( file, QStringLiteral("application/x-gzip") );
+    KTar ark( file, QStringLiteral("application/gzip") );
     ark.open( QIODevice::ReadOnly );
     const KArchiveDirectory* dir = ark.directory();
 //    assert( dir );
@@ -758,7 +747,7 @@ bool KigFilterNative::save07( const KigDocument& data, const QString& outfile )
     else
       return false;
 
-    QString tmpfile = tempdir + tempname + ".kig";
+    const QString tmpfile = tempdir + QLatin1Char('/') + tempname + ".kig";
     QFile ftmpfile( tmpfile );
     if ( !ftmpfile.open( QIODevice::WriteOnly ) )
       return false;
@@ -771,7 +760,7 @@ bool KigFilterNative::save07( const KigDocument& data, const QString& outfile )
     qDebug() << "tmp saved file: " << tmpfile;
 
     // creating the archive and adding our file
-    KTar ark( outfile,  QStringLiteral("application/x-gzip") );
+    KTar ark( outfile,  QStringLiteral("application/gzip") );
     ark.open( QIODevice::WriteOnly );
     ark.addLocalFile( tmpfile, tempname + ".kig" );
     ark.close();
